@@ -55,18 +55,21 @@ class BaseContainer:
                 base_url=ETHERSCAN_BASE_URL,
                 rest_client=self.rest_client
             )
-            self.contract_transactions_repo = ContractTransactionsRepo(
-                mg_client=self.mg_client,
-            )
+            
+            if MONGO_URI is not None:
+                self.contract_transactions_repo = ContractTransactionsRepo(
+                    mg_client=self.mg_client,
+                )
 
-            self.contract_logs_repo = ContractLogsRepo(
-                mg_client=self.mg_client,
-            )
-            self.transaction_sync_service = TransactionSyncService(
-                contract_transactions_repo=self.contract_transactions_repo,
-                contract_logs_repo=self.contract_logs_repo,
-                etherscan_service=self.etherscan_service,
-            )
+                self.contract_logs_repo = ContractLogsRepo(
+                    mg_client=self.mg_client,
+                )
+                
+                self.transaction_sync_service = TransactionSyncService(
+                    contract_transactions_repo=self.contract_transactions_repo,
+                    contract_logs_repo=self.contract_logs_repo,
+                    etherscan_service=self.etherscan_service,
+                )
         else:
             print(
                 "⚠️ skipped EtherscanService init, missing ETHERSCAN_API_KEY and ETHERSCAN_BASE_URL")
